@@ -100,8 +100,9 @@ use Data::Dumper;
 
 use constant DEBUG => 0;
 
-use vars '@ISA';
+use vars qw(@ISA $VERSION);
 @ISA = qw(Bio::Root::Root Bio::SeqI Bio::Das::SegmentI Bio::DB::Das::Chado);
+$VERSION = 0.25;
 
 #use overload '""' => 'asString';
 
